@@ -1,5 +1,5 @@
 from aif360.algorithms.inprocessing.adversarial_debiasing import AdversarialDebiasing
-from Utilities.generate_binary_dataset import generate_binary_label_dataset
+from generate_binary_dataset import generate_binary_label_dataset
 import tensorflow as tf
 
 class Fair_Model():
