@@ -1,5 +1,5 @@
 from aif360.algorithms.postprocessing.reject_option_classification import RejectOptionClassification
-from Utilities.generate_binary_dataset import generate_binary_label_dataset
+from generate_binary_dataset import generate_binary_label_dataset
 
 def Postprocessing(reweighted_data, pred, label, unprivileged_groups, privileged_groups, protected_attribute, favorable_label, unfavorable_label, threshold=0.01):
     reweighted_binary_dataset = generate_binary_label_dataset(reweighted_data, label, protected_attribute, favorable_label, unfavorable_label)
